@@ -1,23 +1,34 @@
 #' Estimate well surface area
 #' 
 #' Estimate geometry surface area of plastic in well plate based on well plate
-#' format suggested values from Corning.  option.plastic == T (default) give
-#' nonzero surface area (sarea, m^2) option.bottom == T (default) includes
+#' format suggested values from Corning.  option.plastic == TRUE (default) give
+#' nonzero surface area (sarea, m^2) option.bottom == TRUE (default) includes
 #' surface area of the bottom of the well in determining sarea.  Optionally
 #' include user values for working volume (v_working, m^3) and surface area.
 #' 
 #' 
 #' @param tcdata A data table with well_number corresponding to plate format,
 #' optionally include v_working, sarea, option.bottom, and option.plastic
+#' 
 #' @param this.well_number For single value, plate format default is 384, used
 #' if is.na(tcdata)==TRUE
+#' 
 #' @param this.cell_yield For single value, optionally supply cell_yield,
 #' otherwise estimated based on well number
+#' 
 #' @param this.v_working For single value, optionally supply working volume,
 #' otherwise estimated based on well number (m^3)
-#'
-#' @return tcdata, A data table with well_number, sarea (surface area, m^2),
-#' cell_yield (# cells), v_working (m^3), v_total (m^3) per well
+#' 
+#' @return A data table composed of any input data.table \emph{tcdata}
+#' with only the following columns either created or altered by this function:  
+#' \tabular{ccc}{
+#' \strong{Column Name} \tab \strong{Description} \tab \strong{Units} \cr
+#' well_number \tab number of wells on plate \tab \cr
+#' sarea \tab surface area \tab m^2 \cr
+#' cell_yield \tab number of cells \tab cells \cr 
+#' v_working \tab working (filled) volume of each well \tab uL \cr
+#' v_total \tab total volume of each well \tab uL \cr
+#' }
 #'
 #' @author Greg Honda
 #'
@@ -80,7 +91,7 @@ armitage_estimate_sarea <- function(tcdata = NA, # optionally supply columns v_w
     .[is.na(sarea),sarea:=sarea_c] %>%
     .[is.na(cell_yield),cell_yield:=as.double(cell_yield_est)]
 
-  return(tcdata)
+   return(tcdata)
 }
 
 
@@ -96,32 +107,60 @@ armitage_estimate_sarea <- function(tcdata = NA, # optionally supply columns v_w
 #' 
 #' 
 #' @param casrn.vector For vector or single value, CAS number
+#' 
 #' @param nomconc.vector For vector or single value, micromolar nominal 
 #' concentration (e.g. AC50 value)
+#' 
 #' @param this.well_number For single value, plate format default is 384, used
 #' if is.na(tcdata)==TRUE
+#' 
 #' @param this.FBSf Fraction fetal bovine serum, must be entered by user.
+#' 
 #' @param tcdata A data.table with casrn, nomconc, MP, gkow, gkaw, gswat, sarea,
 #' v_total, v_working. Otherwise supply single values to this.params.
+#' 
 #' @param this.sarea Surface area per well (m^2)
+#' 
 #' @param this.v_total Total volume per well (m^3)
+#' 
 #' @param this.v_working Working volume per well (m^3)
+#' 
 #' @param this.cell_yield Number of cells per well
+#' 
 #' @param this.Tsys System temperature (degrees C)
+#' 
 #' @param this.Tref Reference temperature (degrees K)
+#' 
 #' @param this.option.kbsa2 Use alternative bovine-serum-albumin partitioning
 #' model
+#' 
 #' @param this.option.swat2 Use alternative water solubility correction
+#' 
 #' @param this.pseudooct Pseudo-octanol cell storage lipid content
+#' 
 #' @param this.memblip Membrane lipid content of cells
+#' 
 #' @param this.nlom Structural protein conent of cells
+#' 
 #' @param this.P_nlom Proportionality constant to octanol structural protein
+#' 
 #' @param this.P_dom Proportionality constant to dissolve organic material
+#' 
 #' @param this.P_cells Proportionality constant to octanol storage lipid
+#' 
 #' @param this.csalt Ionic strength of buffer, mol/L
+#' 
 #' @param this.celldensity Cell density kg/L, g/mL
+#' 
 #' @param this.cellmass Mass per cell, ng/cell
+#'
 #' @param this.f_oc 1, everything assumed to be like proteins
+#' 
+#' @param this.conc_ser_alb 24 g/L, mass concentration of albumin in serum.
+#' 
+#' @param this.conc_ser_lip 1.9 g/L, mass concentration of lipids in serum.
+#' 
+#' @param this.Vdom 0 ml, the volume of dissolved organic matter (DOM)
 #'
 #' @return
 #' \tabular{lll}{
@@ -138,7 +177,7 @@ armitage_estimate_sarea <- function(tcdata = NA, # optionally supply columns v_w
 #' gswat \tab log10 Water solubility \tab log10 mol/L \cr         
 #' MP \tab Melting Point \tab degrees Celsius \cr           
 #' MW \tab Molecular Weight \tab g/mol \cr            
-#' gkaw \tab air to water PC \tab (mol/m3)/(mol/m3) \cr
+#' gkaw \tab air-water partition coefficient \tab (mol/m3)/(mol/m3) \cr          
 #' dsm \tab \tab \cr           
 #' duow \tab \tab \cr          
 #' duaw \tab \tab \cr          
@@ -243,7 +282,7 @@ armitage_estimate_sarea <- function(tcdata = NA, # optionally supply columns v_w
 #' # Check to see if we have info on the chemical:
 #' "793-24-8" %in% get_cheminfo()
 #' 
-#' # Since we don't look up phys-chem from dashboard:
+#' # Since we don't have any info, let's look up phys-chem from dashboard:
 #' cheminfo <- data.frame(
 #'   Compound="6-PPD",
 #'   CASRN="793-24-8",
@@ -284,7 +323,7 @@ armitage_estimate_sarea <- function(tcdata = NA, # optionally supply columns v_w
 armitage_eval <- function(casrn.vector = NA_character_, # vector of CAS numbers
                           nomconc.vector = 1, # nominal concentration vector (e.g. apparent AC50 values)
                           this.well_number = 384,
-                          this.FBSf = NA_real_, # Must be set if not in tcdata, this is the most senstive parameter in the model
+                          this.FBSf = NA_real_, # Must be set if not in tcdata, this is the most senstive parameter in the model.
                           tcdata = NA, # A data.table with casrn, ac50, and well_number or all of sarea, v_total, and v_working
                           this.sarea = NA_real_,
                           this.v_total = NA_real_,
@@ -292,8 +331,8 @@ armitage_eval <- function(casrn.vector = NA_character_, # vector of CAS numbers
                           this.cell_yield = NA_real_,
                           this.Tsys = 37,
                           this.Tref = 298.15,
-                          this.option.kbsa2 = F,
-                          this.option.swat2 = F,
+                          this.option.kbsa2 = FALSE,
+                          this.option.swat2 = FALSE,
                           this.pseudooct = 0.01, # storage lipid content of cells
                           this.memblip = 0.04, # membrane lipid content of cells
                           this.nlom = 0.20, # structural protein content of cells
@@ -303,7 +342,10 @@ armitage_eval <- function(casrn.vector = NA_character_, # vector of CAS numbers
                           this.csalt = 0.15, # ionic strength of buffer, mol/L
                           this.celldensity=1, # kg/L g/mL  mg/uL
                           this.cellmass = 3, #ng/cell
-                          this.f_oc = 1 # everything assumed to be like proteins
+                          this.f_oc = 1, # everything assumed to be like proteins
+                          this.conc_ser_alb = 24, # g/L mass concentration of albumin in serum.
+                          this.conc_ser_lip = 1.9, # g/L mass concentration of lipids in serum.
+                          this.Vdom = 0 # ml the volume of dissolved organic matter (DOM)
 ){
   # this.Tsys <- 37
   # this.Tref <- 298.15
@@ -320,8 +362,8 @@ armitage_eval <- function(casrn.vector = NA_character_, # vector of CAS numbers
   # this.celldensity<-1 # kg/L g/mL  mg/uL
   # this.cellmass <- 3 #ng/cell
   # this.f_oc <- 1 # everything assumed to be like proteins
-
-
+  
+  
   #R CMD CHECK throws notes about "no visible binding for global variable", for
   #each time a data.table column name is used without quotes. To appease R CMD
   #CHECK, a variable has to be created for each of these column names and set to
@@ -338,8 +380,9 @@ armitage_eval <- function(casrn.vector = NA_character_, # vector of CAS numbers
   mprecip<-xwat_s<-xair<-xbsa<-xslip<-xdom<-xcells<-xplastic<-xprecip<-NULL
   ccells<-eta_free <- cfree.invitro <- nomconc <- well_number <- NULL
   logHenry <- logWSol <- NULL
+  conc_ser_alb <- conc_ser_lip <- Vbm <- NULL
   #End R CMD CHECK appeasement.
-
+  
   if(all(is.na(tcdata))){
     tcdata <- data.table(casrn = casrn.vector,
                          nomconc = nomconc.vector,
@@ -371,12 +414,14 @@ armitage_eval <- function(casrn.vector = NA_character_, # vector of CAS numbers
     
     if(any(is.na(tcdata[missing.rows, well_number]))){
       print(paste0("Either well_number or geometry must be defined for rows: ", 
-                  paste(which(tcdata[, is.na(sarea) & is.na(well_number)]),collapse = ",")))
+                   paste(which(tcdata[, is.na(sarea) & is.na(well_number)]),collapse = ",")))
       stop()
     }else{
       temp <- armitage_estimate_sarea(tcdata[missing.rows,])
       tcdata[missing.rows,"sarea"] <- temp[,"sarea"]
-      tcdata[missing.rows,"v_total"] <- temp[,"v_total"]
+      if(any(is.na(tcdata[missing.rows,"v_total"]))){
+        tcdata[missing.rows,"v_total"] <- temp[,"v_total"]
+      }
       tcdata[missing.rows,"v_working"] <- temp[,"v_working"]
       tcdata[missing.rows,"cell_yield"] <- temp[,"cell_yield"]
     }
@@ -391,71 +436,77 @@ armitage_eval <- function(casrn.vector = NA_character_, # vector of CAS numbers
                                 chem.cas = casrn)]
   }
   tcdata[, "gkaw" := logHenry - log10(298.15*8.2057338e-5)] # log10 atm-m3/mol to (mol/m3)/(mol/m3)
-
+  
   manual.input.list <- list(Tsys=this.Tsys, Tref=this.Tref,
-                                option.kbsa2=this.option.kbsa2, option.swat2=this.option.swat2,
-                                FBSf=this.FBSf, pseudooct=this.pseudooct, memblip=this.memblip,
-                                nlom=this.nlom, P_nlom=this.P_nlom, P_dom=this.P_dom, P_cells=this.P_cells,
-                                csalt=this.csalt, celldensity=this.celldensity, cellmass=this.cellmass, f_oc=this.f_oc)
-
+                            option.kbsa2=this.option.kbsa2, option.swat2=this.option.swat2,
+                            FBSf=this.FBSf, pseudooct=this.pseudooct, memblip=this.memblip,
+                            nlom=this.nlom, P_nlom=this.P_nlom, P_dom=this.P_dom, P_cells=this.P_cells,
+                            csalt=this.csalt, celldensity=this.celldensity, cellmass=this.cellmass, f_oc=this.f_oc,
+                            conc_ser_alb = this.conc_ser_alb, conc_ser_lip = this.conc_ser_lip, Vdom = this.Vdom)
+  
   check.list <- c("dsm","duow","duaw","dumw",
                   "gkmw","gkcw","gkbsa","gkpl","ksalt")
-
+  
   req.list <- c("Tsys","Tref","option.kbsa2","option.swat2",
-                 "FBSf","pseudooct","memblip","nlom","P_nlom","P_dom","P_cells",
-                 "csalt","celldensity","cellmass","f_oc")
+                "FBSf","pseudooct","memblip","nlom","P_nlom","P_dom","P_cells",
+                "csalt","celldensity","cellmass","f_oc","conc_ser_alb","conc_ser_lip","Vdom")
   if(!all(check.list%in%names(tcdata))){
-  tcdata[,check.list[!(check.list %in% names(tcdata))]] <- as.double(NA)}
-
+    tcdata[,check.list[!(check.list %in% names(tcdata))]] <- as.double(NA)}
+  
   if(!all(req.list%in%names(tcdata))){
-  tcdata[,req.list[!(req.list %in% names(tcdata))]] <- manual.input.list[!(names(manual.input.list) %in% names(tcdata))]}
-
-  R <- 8.3144
-
+    tcdata[,req.list[!(req.list %in% names(tcdata))]] <- manual.input.list[!(names(manual.input.list) %in% names(tcdata))]}
+  
+  R <- 8.3144621 # J/(mol*K)
+  
   tcdata[,cellwat := 1-(pseudooct+memblip+nlom)] %>%
     .[,Tsys:=Tsys+273.15] %>%
     .[,Tcor:=((1/Tsys)-(1/Tref))/(2.303*R)]
-
-
-  tcdata[,Vm:=v_working/1e6] %>% # uL to L
-      .[,Vwell:=v_total/1e6] %>% # uL to L
-      .[,Vair:=Vwell-Vm] %>%
-      .[,Vcells:=cell_yield*(cellmass/1e6)/celldensity/1e6] %>% # cell*(ng/cell)*(1mg/1e6ng)/(mg/uL)*(1uL/L)
-      .[,Valb:=Vm*FBSf*0.733*24/1000] %>%
-      .[,Vslip:=Vm*FBSf*1.9/1000] %>%
-      .[,Vdom:=0]
-
-  tcdata[is.na(dsm),dsm:=56.5] %>%
-    .[is.na(duow),duow:=-20000] %>%
-    .[is.na(duaw),duaw:=60000] %>%
+  
+  
+  tcdata[,Vbm:=v_working/1e6] %>% # uL to L; the volume of bulk medium
+    .[,Vwell:=v_total/1e6] %>% # uL to L; the volume of well
+    #.[,Vair:=Vwell-Vm] %>%
+    .[,Vcells:=cell_yield*(cellmass/1e6)/celldensity/1e6] %>% # cell*(ng/cell)*(1mg/1e6ng)/(mg/uL)*(1uL/L); the volume of cells.
+    .[,Vair:=Vwell-Vbm-Vcells] %>%  # the volume of head space
+    .[,Valb:=Vbm*FBSf*0.733*conc_ser_alb/1000] %>% # the volume of serum albumin
+    .[,Vslip:=Vbm*FBSf*conc_ser_lip/1000] %>% # the volume of serum lipids
+    #.[,Vdom:=0] %>%
+    .[,Vdom:=Vdom/1e6] %>% # uL to L; the volume of Dissolved Organic Matter (DOM)
+    .[,Vm:=Vbm-Valb-Vslip-Vdom] # the volume of medium
+    
+  
+  tcdata[is.na(dsm),dsm:=56.5] %>% #J/(mol*K) # Walden's rule
+    .[is.na(duow),duow:=-20000] %>% # see SI EQC model - in vitro tox test July 2014.xlsm
+    .[is.na(duaw),duaw:=60000] %>% # see SI EQC model - in vitro tox test July 2014.xlsm
     .[is.na(dumw),dumw:=duow] %>%
     .[,MP:= MP+273.15] %>%
-    .[,F_ratio:=exp(-(dsm/R)*(MP/Tsys))] %>% #Walden's rule
+    #.[,F_ratio:=exp(-(dsm/R)*(MP/Tsys))] %>% 
+    .[,F_ratio:=10^(0.01*(Tsys-MP))] %>% 
     .[MP<=Tsys,F_ratio:=1]
-
+  
   tcdata[,gs1.GSE:=0.5-gkow] %>%
     .[,gs1.GSE:=gs1.GSE-(-1*duow)*Tcor] %>%
     .[,s1.GSE:=10^gs1.GSE] %>%
     .[MP>298.15,gss.GSE:=0.5-0.01*((MP-273.15)-25)-gkow] %>%
     .[MP>298.15,gss.GSE:=gss.GSE-(-1*duow)*Tcor] %>%
     .[MP>298.15,ss.GSE:=10^gss.GSE] %>%
-    .[is.na(gkmw),gkmw:=1.01*gkow + 0.12] %>%
+    .[is.na(gkmw),gkmw:=1.01*gkow + 0.12] %>% 
     .[,gkmw:=gkmw-dumw*Tcor] %>%
     .[,kmw:=10^gkmw] %>%
-    .[,gkow:=gkow-duow*Tcor] %>% # check this
+    .[,gkow:=gkow-duow*Tcor] %>%
     .[,kow:=10^gkow] %>%
     .[,gkaw:=gkaw-duaw*Tcor] %>%
     .[,kaw := 10^gkaw] %>%
     .[,gswat:=gswat-(-1*duow)*Tcor] %>%
     .[,swat:=10^gswat]
-
-  tcdata[is.na(gkpl),gkpl:=0.97*gkow-6.94] %>%
+  
+  tcdata[is.na(gkpl),gkpl:=0.97*gkow-6.94] %>% 
     .[,kpl:=10^gkpl] %>%
     .[!(is.na(gkcw)),gkcw:=gkcw-duow*Tcor] %>%
     .[is.na(gkcw),gkcw:=log10(P_cells*pseudooct*kow + memblip*kmw +
                                 P_nlom*nlom*kow + cellwat)] %>%
     .[,kcw:=10^gkcw]
-
+  
   tcdata[!(is.na(gkbsa)),gkbsa:=gkbsa-duow*Tcor] %>%
     .[!(is.na(gkbsa)),kbsa:=10^gkbsa]
 
@@ -481,21 +532,21 @@ armitage_eval <- function(casrn.vector = NA_character_, # vector of CAS numbers
 
   tcdata[,soct_L:=kow*swat_L] %>%
     .[,scell_L:=kcw*swat_L]
-
+  
   tcdata[,nomconc := nomconc/1e6] %>% # umol/L to mol/L
     .[,cinit:= nomconc] %>%
-    .[,mtot:= nomconc*Vm] %>% # total moles
+    .[,mtot:= nomconc*Vbm] %>%
     .[,cwat:=mtot/(kaw*Vair + Vm + kbsa*Valb +
-                     P_cells*kow*Vslip + P_dom*f_oc*Vdom + kcw*Vcells +
+                     P_cells*kow*Vslip + kow*P_dom*f_oc*Vdom + kcw*Vcells +
                      1000*kpl*sarea)] %>%
     .[cwat>swat,cwat_s:=swat] %>%
     .[cwat>swat,csat:=1] %>%
     .[cwat<=swat,cwat_s:=cwat] %>%
     .[cwat<=swat,csat:=0] %>%
     .[,activity:=cwat_s/swat_L]
-
+  
   tcdata[,c("cair","calb","cslip","cdom","ccells")] <- 0
-
+  
   tcdata[Vair>0,cair:=kaw*cwat_s] %>%
     .[Valb>0,calb:=kbsa*cwat_s] %>%
     .[Vslip>0,cslip:=kow*cwat_s*P_cells] %>%
@@ -527,4 +578,3 @@ armitage_eval <- function(casrn.vector = NA_character_, # vector of CAS numbers
   #output mass (mwat_s etc.) in mols
   #output mol fraction xbsa etc.
 }
-
