@@ -12,7 +12,7 @@
 #' the chemical must be identified by either CAS, name, or DTXSIDs
 #'@param parameters Chemical parameters from parameterize_pbtk (for model = 
 #' 'pbtk'), parameterize_3comp (for model = '3compartment), 
-#' parmeterize_1comp(for model = '1compartment') or parameterize_steadystate 
+#' parameterize_1comp(for model = '1compartment') or parameterize_steadystate 
 #' (for model = '3compartmentss'), overrides chem.name and chem.cas.
 #'@param hourly.dose Hourly dose rate mg/kg BW/h.
 #'@param concentration Desired concentration type, 'blood' or default 'plasma'.
@@ -32,7 +32,7 @@
 #'@param ... Additional parameters passed to parameterize function if 
 #'parameters is NULL.
 #'  
-#'@return Steady state concentration in uM units
+#'@return Steady state plasma concentration in mg/L units
 #'
 #'@author Robert Pearce and John Wambaugh
 #'@keywords 3compss
@@ -63,8 +63,8 @@ calc_analytic_css_3compss <- function(chem.name=NULL,
 # Expand on any provided chemical identifiers if possible (if any but not
 # all chemical descriptors are NULL):
   chem_id_list  = list(chem.cas, chem.name, dtxsid)
-  if (any(lapply(chem_id_list, is.null)) &
-      !all(lapply(chem_id_list, is.null))){
+  if (any(unlist(lapply(chem_id_list, is.null))) &
+      !all(unlist(lapply(chem_id_list, is.null)))){
   out <- get_chem_id(
     chem.cas=chem.cas,
     chem.name=chem.name,
@@ -157,7 +157,7 @@ calc_analytic_css_3compss <- function(chem.name=NULL,
       pcs <- predict_partitioning_schmitt(parameters =
           parameters[, param.names.schmitt[param.names.schmitt %in% 
           names(parameters)], with = F])
-    }else if (class(parameters) == "list") {
+    }else if (is(parameters,"list")) {
       pcs <- predict_partitioning_schmitt(parameters =
           parameters[param.names.schmitt[param.names.schmitt %in% 
           names(parameters)]])
@@ -179,7 +179,7 @@ calc_analytic_css_3compss <- function(chem.name=NULL,
     {
       Css <- Css * Rb2p
       
-    }else if(bioactive.free.invivo == T & tolower(concentration) == 'plasma'){
+    }else if(bioactive.free.invivo == TRUE & tolower(concentration) == 'plasma'){
       
       Css <- Css * parameters[['Funbound.plasma']]
       
