@@ -1,32 +1,59 @@
-#' Parameterize_1comp
+#' Parameters for a one compartment (empirical) toxicokinetic model
 #' 
 #' This function initializes the parameters needed in the function solve_1comp.
-#' 
+#' Volume of distribution is estimated by using a modified Schmitt (2008) method
+#' to predict tissue particition coefficients (Pearce et al., 2017) and then
+#' lumping the compartments weighted by tissue volume:
+#'
+#' \if{latex}{
+#' \eqn{V_{d,steady-state} = \Sigma_{i\in tissues}K_{i}V_{i} + V_{plasma}}
+#' }
+#' \if{html}{
+#' V_d,steady-state = Sum over all tissues (K_i * V_i) + V_plasma
+#' }
+#'
+#' where K_i is the tissue:unbound plasma concentration partition coefficient
+#' for tissue i.
+#'
 #' @param chem.cas Chemical Abstract Services Registry Number (CAS-RN) -- the 
 #' chemical must be identified by either CAS, name, or DTXISD
+#' 
 #' @param chem.name Chemical name (spaces and capitalization ignored) --  the 
 #' chemical must be identified by either CAS, name, or DTXISD
+#' 
 #' @param dtxsid EPA's DSSTox Structure ID (\url{https://comptox.epa.gov/dashboard})  
 #' -- the chemical must be identified by either CAS, name, or DTXSIDs
+#' 
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").
+#' 
 #' @param default.to.human Substitutes missing rat values with human values if
 #' true.
-#' @param adjusted.Funbound.plasma Uses adjusted Funbound.plasma when set to
-#' TRUE along with volume of distribution calculated with this value.
+#' 
+#' @param adjusted.Funbound.plasma Uses Pearce et al. (2017) lipid binding adjustment
+#' for Funbound.plasma (which impacts volume of distribution) when set to TRUE (Default).
+#' 
+#' @param adjusted.Clint Uses Kilford et al. (2008) hepatocyte incubation
+#' binding adjustment for Clint when set to TRUE (Default).
+#' 
 #' @param regression Whether or not to use the regressions in calculating
 #' partition coefficients in volume of distribution calculation.
+#' 
 #' @param restrictive.clearance In calculating elimination rate and hepatic
 #' bioavailability, protein binding is not taken into account (set to 1) in
 #' liver clearance if FALSE.
+#' 
 #' @param well.stirred.correction Uses correction in calculation of hepatic
 #' clearance for well-stirred model if TRUE.  This assumes clearance relative
 #' to amount unbound in whole blood instead of plasma, but converted to use
 #' with plasma concentration.
+#' 
 #' @param suppress.messages Whether or not to suppress messages.
+#' 
 #' @param clint.pvalue.threshold Hepatic clearance for chemicals where the in
 #' vitro clearance assay result has a p-value greater than the threshold are
 #' set to zero.
+#' 
 #' @param minimum.Funbound.plasma Monte Carlo draws less than this value are set 
 #' equal to this value (default is 0.0001 -- half the lowest measured Fup in our
 #' dataset).
@@ -51,15 +78,24 @@
 #'
 #' @author John Wambaugh and Robert Pearce
 #'
-#' @references Pearce, Robert G., et al. "Httk: R package for high-throughput 
+#' @references 
+#' Pearce, Robert G., et al. "Httk: R package for high-throughput 
 #' toxicokinetics." Journal of statistical software 79.4 (2017): 1.
 #'
+#' Schmitt, Walter. "General approach for the calculation of tissue 
+#' to plasma partition coefficients." Toxicology in vitro 22.2 (2008): 457-467.
+#'
+#' Pearce, Robert G., et al. "Evaluation and calibration of high-throughput 
+#' predictions of chemical distribution to tissues." Journal of pharmacokinetics 
+#' and pharmacodynamics 44.6 (2017): 549-565.
+#'
 #' Kilford, P. J., Gertz, M., Houston, J. B. and Galetin, A.
 #' (2008). Hepatocellular binding of drugs: correction for unbound fraction in
 #' hepatocyte incubations using microsomal binding or drug lipophilicity data.
 #' Drug Metabolism and Disposition 36(7), 1194-7, 10.1124/dmd.108.020834.
 #'
 #' @keywords Parameter 1compartment
+#'
 #' @examples
 #' 
 #'  parameters <- parameterize_1comp(chem.name='Bisphenol-A',species='Rat')
@@ -77,6 +113,7 @@ parameterize_1comp <- function(
                         species='Human',
                         default.to.human=FALSE,
                         adjusted.Funbound.plasma=TRUE,
+                        adjusted.Clint=TRUE,
                         regression=TRUE,
                         restrictive.clearance=TRUE,
                         well.stirred.correction=TRUE,
@@ -126,6 +163,7 @@ parameterize_1comp <- function(
                                   default.to.human=default.to.human,
                                   adjusted.Funbound.plasma=
                                     adjusted.Funbound.plasma,
+                                  adjusted.Clint=adjusted.Clint,
                                   restrictive.clearance=restrictive.clearance,
                                   clint.pvalue.threshold=clint.pvalue.threshold,
                                   minimum.Funbound.plasma=
@@ -140,6 +178,7 @@ parameterize_1comp <- function(
                          suppress.messages=TRUE,
                          default.to.human=default.to.human,
                          adjusted.Funbound.plasma=adjusted.Funbound.plasma,
+                         adjusted.Clint=adjusted.Clint,
                          regression=regression,
                          restrictive.clearance=restrictive.clearance,
                          well.stirred.correction=well.stirred.correction,
