@@ -18,7 +18,7 @@
 #' AUC is the area under the curve of the plasma concentration.
 #' 
 #' Model Figure 
-#' \if{html}{\figure{pbtk.png}{options: width="60\%" alt="Figure: PBTK Model
+#' \if{html}{\figure{pbtk.jpg}{options: width="60\%" alt="Figure: PBTK Model
 #' Schematic"}}
 #' \if{latex}{\figure{pbtk.pdf}{options: width=12cm alt="Figure: PBTK Model
 #' Schematic"}}
@@ -41,8 +41,8 @@
 #' overrides chem.name and chem.cas.
 #' @param days Length of the simulation.
 #' @param tsteps The number of time steps per hour.
-#' @param daily.dose Total daily dose, mg/kg BW.
-#' @param dose Amount of a single dose, mg/kg BW. 
+#' @param daily.dose Total daily dose, defaults to mg/kg BW.
+#' @param dose Amount of a single dose, defaults to mg/kg BW. 
 #' @param doses.per.day Number of doses per day.
 #' @param initial.values Vector containing the initial concentrations or
 #' amounts of the chemical in specified tissues with units corresponding to
@@ -52,8 +52,11 @@
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", "Mouse", or
 #' default "Human").
 #' @param iv.dose Simulates a single i.v. dose if true.
-#' @param output.units Desired units (either "mg/L", "mg", "umol", or default
-#' "uM").
+#' @param input.units Input units of interest assigned to dosing, defaults to
+#' mg/kg BW
+#' @param output.units A named vector of output units expected for the model
+#' results. Default, NULL, returns model results in units specified in the
+#' 'modelinfo' file. See table below for details.
 #' @param method Method used by integrator (deSolve).
 #' @param rtol Argument passed to integrator (deSolve).
 #' @param atol Argument passed to integrator (deSolve).
@@ -153,14 +156,16 @@ solve_pbtk <- function(chem.name = NULL,
                     days=10,
                     tsteps = 4, # tsteps is number of steps per hour
                     daily.dose = NULL,
-                    dose = NULL, # Assume dose is in mg/kg BW/day  
+                    dose = NULL,  
                     doses.per.day=NULL,
                     initial.values=NULL,
                     plots=FALSE,
                     suppress.messages=FALSE,
                     species="Human",
                     iv.dose=FALSE,
-                    output.units='uM',
+                    input.units='mg/kg',
+                    # output.units='uM',
+                    output.units=NULL,
                     method="lsoda",rtol=1e-8,atol=1e-12,
                     default.to.human=FALSE,
                     recalc.blood2plasma=FALSE,
@@ -168,7 +173,7 @@ solve_pbtk <- function(chem.name = NULL,
                     dosing.matrix=NULL,
                     adjusted.Funbound.plasma=TRUE,
                     regression=TRUE,
-                    restrictive.clearance = T,
+                    restrictive.clearance = TRUE,
                     minimum.Funbound.plasma=0.0001,
                     monitor.vars=NULL,
                     ...)
@@ -194,6 +199,7 @@ solve_pbtk <- function(chem.name = NULL,
     monitor.vars=monitor.vars,
     suppress.messages=suppress.messages,
     species=species,
+    input.units=input.units,
     output.units=output.units,
     method=method,rtol=rtol,atol=atol,
     recalc.blood2plasma=recalc.blood2plasma,
