@@ -1,6 +1,5 @@
 #R CMD BATCH --no-timing --no-restore --no-save adddata_test.R adddata_test.Rout
 library(httk)
-options(warn=-1)
 
 # Number of chemicals distributed with the package:
 num.chems <- length(get_cheminfo())
@@ -12,7 +11,7 @@ fake <- data.frame(Compound="Tester",
                    logP=3.5,
                    Fup=0.1,
                    Clint=0.1,
-                   Clint.pValue=0.001,stringsAsFactors=F)
+                   Clint.pValue=0.001,stringsAsFactors=FALSE)
 
 chem.physical_and_invitro.data <- add_chemtable(
   fake,
@@ -31,14 +30,14 @@ chem.physical_and_invitro.data <- add_chemtable(
 
 calc_css(chem.name="Tester")
 
-load_sipes2017()
+#load_sipes2017()
 
 # We should have the ADMet Predicted chemicals from Sipes et al. (2017),
 # this one is a good test since the logP is nearly 10!
-calc_css(chem.cas="26040-51-7")
+#calc_css(chem.cas="26040-51-7")
 
 #Let's see how many chemicals we have now with the Sipes (2017) data loaded)=:
-length(get_cheminfo())
+#length(get_cheminfo())
 
 #Now let's reset
 reset_httk()
